Accepting request 977568 from Java:packages

maven 3.8.5 / jansi 2.4.0 and fixes for building with them

OBS-URL: https://build.opensuse.org/request/show/977568
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/maven?expand=0&rev=12
This commit is contained in:
Dominique Leuenberger 2022-05-17 15:24:17 +00:00 committed by Git OBS Bridge
commit 6a1213aa02
16 changed files with 430 additions and 3942 deletions

View File

@ -1,14 +1,14 @@
From 46041685a82b861bc8616bb603e341adb740a302 Mon Sep 17 00:00:00 2001
From 6e8f6a1b27c09d0a84fb5f3b7269cf5840db04f8 Mon Sep 17 00:00:00 2001
From: Michael Simacek <msimacek@redhat.com>
Date: Wed, 1 Feb 2017 14:54:26 +0100
Subject: [PATCH 1/3] Adapt mvn script
Subject: [PATCH 1/7] Adapt mvn script
---
apache-maven/src/bin/mvn | 19 ++++++++++++++++---
1 file changed, 16 insertions(+), 3 deletions(-)
diff --git a/apache-maven/src/bin/mvn b/apache-maven/src/bin/mvn
index a554c66..818cf70 100755
index dfa384b8e..8c03825ed 100755
--- a/apache-maven/src/bin/mvn
+++ b/apache-maven/src/bin/mvn
@@ -22,7 +22,7 @@
@ -20,7 +20,7 @@ index a554c66..818cf70 100755
# MAVEN_OPTS (Optional) Java runtime options used when Maven is executed.
# MAVEN_SKIP_RC (Optional) Flag to disable loading of mavenrc files.
# -----------------------------------------------------------------------------
@@ -37,12 +37,24 @@
@@ -37,12 +37,24 @@ if [ -z "$MAVEN_SKIP_RC" ] ; then
. /etc/mavenrc
fi
@ -45,7 +45,7 @@ index a554c66..818cf70 100755
# OS specific support. $var _must_ be set to either true or false.
cygwin=false;
mingw=false;
@@ -67,7 +79,8 @@
@@ -67,7 +79,8 @@ done
saveddir=`pwd`
@ -55,7 +55,7 @@ index a554c66..818cf70 100755
# make it fully qualified
MAVEN_HOME=`cd "$MAVEN_HOME" && pwd`
@@ -105,7 +118,7 @@
@@ -105,7 +118,7 @@ if [ ! -x "$JAVACMD" ] ; then
exit 1
fi
@ -65,5 +65,5 @@ index a554c66..818cf70 100755
# For Cygwin, switch paths to Windows format before running java
--
2.17.1
2.36.1

View File

@ -1,7 +1,7 @@
From 7610a10691e680db00edcbd4ce6767a30641cd71 Mon Sep 17 00:00:00 2001
From 4d259917ec0a1e73a9bbf23e0737acd64727b802 Mon Sep 17 00:00:00 2001
From: Michael Simacek <msimacek@redhat.com>
Date: Tue, 6 Jun 2017 13:47:43 +0200
Subject: [PATCH 2/4] Invoke logback via reflection
Subject: [PATCH 2/7] Invoke logback via reflection
---
.../logging/impl/LogbackConfiguration.java | 19 ++++++++++++++-----
@ -49,5 +49,5 @@ index 5d9fab744..ced38cb5a 100644
@Override
--
2.21.0
2.36.1

View File

@ -1,7 +1,7 @@
From c8933d155694ce37b1d4be59a744c8f7cbde6bb5 Mon Sep 17 00:00:00 2001
From 507d1090563596d0752918ec3572a8c4a4130d2b Mon Sep 17 00:00:00 2001
From: Mikolaj Izdebski <mizdebsk@redhat.com>
Date: Mon, 1 Jul 2019 09:51:56 +0200
Subject: [PATCH 4/4] Use non-shaded HTTP wagon
Subject: [PATCH 3/7] Use non-shaded HTTP wagon
---
apache-maven/pom.xml | 15 ---------------
@ -9,7 +9,7 @@ Subject: [PATCH 4/4] Use non-shaded HTTP wagon
2 files changed, 16 deletions(-)
diff --git a/apache-maven/pom.xml b/apache-maven/pom.xml
index 2686570af..d22ae121d 100644
index 7ff412767..b15091576 100644
--- a/apache-maven/pom.xml
+++ b/apache-maven/pom.xml
@@ -63,21 +63,6 @@ under the License.
@ -32,13 +32,13 @@ index 2686570af..d22ae121d 100644
- </exclusion>
- </exclusions>
</dependency>
<!-- This is included in Wagon HTTP.
We are just making the dependency explicit
<dependency>
<groupId>org.slf4j</groupId>
diff --git a/pom.xml b/pom.xml
index 237cdc39e..85436c54d 100644
index c319cae26..42afab5f1 100644
--- a/pom.xml
+++ b/pom.xml
@@ -334,7 +334,6 @@
@@ -333,7 +333,6 @@ under the License.
<groupId>org.apache.maven.wagon</groupId>
<artifactId>wagon-http</artifactId>
<version>${wagonVersion}</version>
@ -47,5 +47,5 @@ index 237cdc39e..85436c54d 100644
<exclusion>
<groupId>commons-logging</groupId>
--
2.21.0
2.36.1

View File

@ -0,0 +1,96 @@
From 710c46095ed8b34c0cb7c2e69379db044eb026e9 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Thu, 5 Sep 2019 15:21:04 +0200
Subject: [PATCH 4/7] Remove dependency on powermock
---
.../StringSearchModelInterpolatorTest.java | 66 -------------------
1 file changed, 66 deletions(-)
diff --git a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
index c95e37271..aafafa52f 100644
--- a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
+++ b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
@@ -36,8 +36,6 @@
import static org.hamcrest.CoreMatchers.anyOf;
import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;
-import static org.powermock.reflect.Whitebox.getField;
-import static org.powermock.reflect.Whitebox.getInternalState;
/**
* @author jdcasey
@@ -375,70 +373,6 @@ public void testInterpolateObjectWithPomFile()
) ) );
}
- public void testNotInterpolateObjectWithFile()
- throws Exception
- {
- Model model = new Model();
-
- File baseDir = new File( System.getProperty( "user.dir" ) );
-
- Properties p = new Properties();
-
- ObjectWithNotInterpolatedFile obj = new ObjectWithNotInterpolatedFile( baseDir );
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest( p );
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject( obj, model, new File( "." ), config, collector );
- assertProblemFree( collector );
-
- //noinspection unchecked
- Map<Class<?>, ?> cache =
- (Map<Class<?>, ?>) getField( StringSearchModelInterpolator.class, "CACHED_ENTRIES" )
- .get( null );
-
- Object objCacheItem = cache.get( Object.class );
- Object fileCacheItem = cache.get( File.class );
-
- assertNotNull( objCacheItem );
- assertNotNull( fileCacheItem );
-
- assertThat( ( (Object[]) getInternalState( objCacheItem, "fields" ) ).length, is( 0 ) );
- assertThat( ( (Object[]) getInternalState( fileCacheItem, "fields" ) ).length, is( 0 ) );
- }
-
- public void testNotInterpolateFile()
- throws Exception
- {
- Model model = new Model();
-
- File baseDir = new File( System.getProperty( "user.dir" ) );
-
- Properties p = new Properties();
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest( p );
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject( baseDir, model, new File( "." ), config, collector );
- assertProblemFree( collector );
-
- //noinspection unchecked
- Map<Class<?>, ?> cache =
- (Map<Class<?>, ?>) getField( StringSearchModelInterpolator.class, "CACHED_ENTRIES" )
- .get( null );
-
- Object fileCacheItem = cache.get( File.class );
-
- assertNotNull( fileCacheItem );
-
- assertThat( ( (Object[]) getInternalState( fileCacheItem, "fields" ) ).length, is( 0 ) );
- }
-
-
public void testConcurrentInterpolation()
throws Exception
{
--
2.36.1

View File

@ -1,25 +1,25 @@
From b23d2957440cb4ff06a289b4864f782794b45f52 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Fri, 17 Dec 2021 13:05:49 +0100
Subject: [PATCH] Port to maven-resolver 1.7.2
---
.../org/apache/maven/repository/internal/MavenAetherModule.java | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
index 41e98aaea..d72e3c0f3 100644
--- a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
+++ b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
@@ -28,7 +28,7 @@
import org.apache.maven.model.building.DefaultModelBuilderFactory;
import org.apache.maven.model.building.ModelBuilder;
-import org.eclipse.aether.impl.AetherModule;
+import org.eclipse.aether.impl.guice.AetherModule;
import org.eclipse.aether.impl.ArtifactDescriptorReader;
import org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.impl.VersionRangeResolver;
--
2.31.1
From 64c73b39d35ac08666cb1f1eb0be26150bf4a821 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Fri, 17 Dec 2021 13:05:49 +0100
Subject: [PATCH 5/7] Port to maven-resolver 1.7.2
---
.../org/apache/maven/repository/internal/MavenAetherModule.java | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
index 41e98aaea..d72e3c0f3 100644
--- a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
+++ b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
@@ -28,7 +28,7 @@
import org.apache.maven.model.building.DefaultModelBuilderFactory;
import org.apache.maven.model.building.ModelBuilder;
-import org.eclipse.aether.impl.AetherModule;
+import org.eclipse.aether.impl.guice.AetherModule;
import org.eclipse.aether.impl.ArtifactDescriptorReader;
import org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.impl.VersionRangeResolver;
--
2.36.1

View File

@ -0,0 +1,37 @@
From 8b9a2cb2879012dfa2e666a6c33be183da532d47 Mon Sep 17 00:00:00 2001
From: Mikolaj Izdebski <mizdebsk@redhat.com>
Date: Fri, 22 Apr 2022 11:15:38 +0200
Subject: [PATCH 6/7] Restore DefaultModelValidator compatibility with Maven
3.5.4
---
.../maven/model/validation/DefaultModelValidator.java | 6 ++++++
1 file changed, 6 insertions(+)
diff --git a/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java b/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
index f77321c16..4ed22f3ed 100644
--- a/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
+++ b/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
@@ -44,6 +44,7 @@
import org.apache.maven.model.building.ModelProblem.Version;
import org.apache.maven.model.building.ModelProblemCollector;
import org.apache.maven.model.building.ModelProblemCollectorRequest;
+import org.apache.maven.model.interpolation.DefaultModelVersionProcessor;
import org.apache.maven.model.interpolation.ModelVersionProcessor;
import org.codehaus.plexus.util.StringUtils;
@@ -85,6 +86,11 @@
private ModelVersionProcessor versionProcessor;
+ public DefaultModelValidator()
+ {
+ this( new DefaultModelVersionProcessor() );
+ }
+
@Inject
public DefaultModelValidator( ModelVersionProcessor versionProcessor )
{
--
2.36.1

View File

@ -0,0 +1,158 @@
From c8ecbea0dd63d065376768e8cae571a15aa48ae8 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Fridrich=20=C5=A0trba?= <fridrich.strba@bluewin.ch>
Date: Fri, 13 May 2022 17:34:20 +0200
Subject: [PATCH 7/7] Fix build with qdox-2.0.1
---
.../org/apache/maven/plugin/DefaultExtensionRealmCache.java | 2 +-
.../org/apache/maven/plugin/DefaultPluginArtifactsCache.java | 2 +-
.../java/org/apache/maven/plugin/DefaultPluginRealmCache.java | 2 +-
.../java/org/apache/maven/plugin/ExtensionRealmCache.java | 4 ++--
.../java/org/apache/maven/plugin/PluginArtifactsCache.java | 4 ++--
.../main/java/org/apache/maven/plugin/PluginRealmCache.java | 4 ++--
.../org/apache/maven/project/DefaultProjectRealmCache.java | 2 +-
.../main/java/org/apache/maven/project/ProjectRealmCache.java | 2 +-
.../maven/project/artifact/DefaultProjectArtifactsCache.java | 2 +-
.../apache/maven/project/artifact/ProjectArtifactsCache.java | 4 ++--
10 files changed, 14 insertions(+), 14 deletions(-)
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
index 6ce63ebbf..e3241c070 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
@@ -157,7 +157,7 @@ public void flush()
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track extension usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
index ee11c4c89..2adb29369 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
@@ -198,7 +198,7 @@ protected static boolean pluginEquals( Plugin a, Plugin b )
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
index 7862b40de..9432d307f 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
@@ -200,7 +200,7 @@ protected static boolean pluginEquals( Plugin a, Plugin b )
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track plugin usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java b/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
index a7f06156a..c74fd644f 100644
--- a/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
@@ -135,7 +135,7 @@ public void flush()
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track record usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java b/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
index 28ac0d620..72d4002c6 100644
--- a/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
@@ -87,6 +87,6 @@ public DependencyFilter getExtensionArtifactFilter()
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
diff --git a/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
index ae59ada4d..83b1b4333 100644
--- a/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
@@ -240,7 +240,7 @@ public void flush()
}
@Override
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
--
2.36.1

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:c140f6a9373ac44d99b688826d907ddffd1124e7ea7c80cc7894d9841f91bd1f
size 5156

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:298bfb6172c134655f4f5608342f9c7bc798918ac165b8ded4af800be184ab9b
size 2774526

View File

@ -1,11 +0,0 @@
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v2
iQEcBAABCgAGBQJhkNSDAAoJEBoqHJS96JaIvpsIAKbTcPc3dfJEp7O3oH6PTcvU
5zeycOGGptm/9k/hCNlzV79YEMDnyZSnEtCBv7/Y3cqEO+WLYeX/0YWxuAIKnBYH
telpXcXVRauV7+eAxgu3nJuIu56eJtGrwndpdYRwkJ94hRhWMG7RsksX3/GtW12u
fH/J/0pYrW1uSIMihk0mEV4lShqhC+mnF6LMM1T3Vl5c9FvTEx0OZWlHd9r10wfD
bX9yXeAt7ckq7EVg0JhW+dpl4Gp5oTwXvNydUMTlOt0NkkC+GHxTDn/BipUt2yau
Sg/J/BKP7/8W0MhnY0tM7x2s8gzc4z7Y3xuzJ+UNCWbO1LREowre8CPVMXoEuSA=
=29QL
-----END PGP SIGNATURE-----

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:0080cd73d1220b5c175f93d5a46579c6f9948771a2b923280ed18d8157bd785b
size 5100

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:a60ddbb333f3addb93e063613a9589f47ed805a572c156075dc1bf4db774c007
size 2783778

View File

@ -1,3 +1,74 @@
-------------------------------------------------------------------
Mon May 16 14:26:42 UTC 2022 - Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.8.5
* Bug
+ [MNG-5180] - Versioning's snapshot version list is not
included in metadata merge
+ [MNG-5561] - Plugin relocation loses configuration
+ [MNG-5982] - The POM for ... is invalid, transitive
dependencies ... while property was overriden
+ [MNG-6326] - Build continues when core extensions aren't
found
+ [MNG-6727] - Using version range in parent and CI Friendly
Version fails
+ [MNG-6802] - FileProfileActivator changes
FileProfileActivator.exists which lets flattened
resolveCiFriendliesOnly depending fail activating profile
+ [MNG-7156] - Parallel build can cause issues between clean
and forked goals
+ [MNG-7335] - [Regression] Parallel build fails due to missing
JAR artifacts in compilePath
+ [MNG-7347] - SessionScoped beans should be singletons for a
given session
+ [MNG-7357] - All Maven Core JARs have unusual entry order
+ [MNG-7362] - DefaultArtifactResolver has spurious "Failure
detected" INFO log
+ [MNG-7374] - Mutating RelocatedArtifact does not retain type
+ [MNG-7386] - ModelMerger$MergingList is not serializable
+ [MNG-7402] - BuildListCalculator never detaches the
classloader
+ [MNG-7417] - Several classes do not set properties properly
for building requests
* New Feature
+ [MNG-7395] - Support interpolation in extensions.xml
+ [MNG-7407] - Introduce a ModelVersionProcessor component to
make CI Friendly Versions pluggable
* Improvement
+ [MNG-6960] - Use RuntimeInformation instead of reading
properties
+ [MNG-7349] - Limit relocation warning message to direct
dependencies only
+ [MNG-7380] - Don't log non-threadsafe warning if only
building a single module
+ [MNG-7381] - Shorten parallel builder thread name to
artifactId, conditionally with groupId
+ [MNG-7385] - Improve documentation on repository metadata
+ [MNG-7400] - Allow more WorkspaceReaders to participate
+ [MNG-7408] - Explain reporting plugin version automatic
selection (in Maven 3)
* Dependency upgrade
+ [MNG-7370] - Upgrade Maven Wagon to 3.5.1
+ [MNG-7384] - Upgrade Maven JAR Plugin to 3.2.2
+ [MNG-7428] - Upgrade Maven Parent to 35
- Modified patches:
* 0001-Adapt-mvn-script.patch
* 0002-Invoke-logback-via-reflection.patch
* 0005-Port-to-maven-resolver-1.7.2.patch
* 0004-Use-non-shaded-HTTP-wagon.patch ->
0003-Use-non-shaded-HTTP-wagon.patch
+ rebase
* qdox-2.0.1.patch -> 0007-Fix-build-with-qdox-2.0.1.patch
+ rebase using git
- Added patches:
* 0004-Remove-dependency-on-powermock.patch
+ Remove the non-interpolated tests that require powermock
* 0006-Restore-DefaultModelValidator-compatibility-with-Mav.patch
+ XMvn was relying on default constructor for the
org.apache.maven.model.validation.DefaultModelValidator,
which is not generated, since a non-default one is defined.
+ This adds the no-parameter constructor back implicitely
-------------------------------------------------------------------
Fri May 13 09:01:43 UTC 2022 - Fridrich Strba <fstrba@suse.com>

File diff suppressed because it is too large Load Diff

View File

@ -20,7 +20,7 @@
%global homedir %{_datadir}/%{name}%{?maven_version_suffix}
%global confdir %{_sysconfdir}/%{name}%{?maven_version_suffix}
Name: maven
Version: 3.8.4
Version: 3.8.5
Release: 0
Summary: Java project management and project comprehension tool
# maven itself is ASL 2.0
@ -31,15 +31,15 @@ URL: https://maven.apache.org/
Source0: http://archive.apache.org/dist/%{name}/%{name}-3/%{version}/source/apache-%{name}-%{version}-src.tar.gz
Source1: maven-bash-completion
Source2: mvn.1
Source3: http://archive.apache.org/dist/%{name}/%{name}-3/%{version}/source/apache-%{name}-%{version}-src.tar.gz.asc
Source4: https://downloads.apache.org/maven/KEYS#/%{name}.keyring
Source10: apache-%{name}-%{version}-build.tar.xz
Patch1: 0001-Adapt-mvn-script.patch
# Downstream-specific, avoids dependency on logback
Patch2: 0002-Invoke-logback-via-reflection.patch
Patch3: qdox-2.0.1.patch
Patch4: 0004-Use-non-shaded-HTTP-wagon.patch
Patch3: 0003-Use-non-shaded-HTTP-wagon.patch
Patch4: 0004-Remove-dependency-on-powermock.patch
Patch5: 0005-Port-to-maven-resolver-1.7.2.patch
Patch6: 0006-Restore-DefaultModelValidator-compatibility-with-Mav.patch
Patch7: 0007-Fix-build-with-qdox-2.0.1.patch
BuildRequires: ant
BuildRequires: apache-commons-cli
BuildRequires: apache-commons-codec
@ -47,17 +47,17 @@ BuildRequires: apache-commons-io
BuildRequires: apache-commons-lang3
BuildRequires: apache-commons-logging
BuildRequires: atinject
BuildRequires: cdi-api
BuildRequires: dos2unix
BuildRequires: fdupes
BuildRequires: glassfish-annotation-api
BuildRequires: google-guice
BuildRequires: guava
BuildRequires: hawtjni-runtime
BuildRequires: httpcomponents-client
BuildRequires: httpcomponents-core
BuildRequires: jansi
BuildRequires: jansi-native
BuildRequires: javapackages-local
BuildRequires: jboss-interceptors-1.2-api
BuildRequires: jcl-over-slf4j
BuildRequires: jdom2
BuildRequires: maven-resolver-api
@ -96,7 +96,7 @@ BuildRequires: mvn(org.apache.maven:maven-parent:pom:)
Requires: %{name}-lib = %{version}-%{release}
Requires(post): aaa_base
Requires(postun):aaa_base
# maven-lib cannot be noarch because of the position of jansi-native.jar
# maven-lib cannot be noarch because of the position of jansi.jar
#BuildArch: noarch
%description
@ -124,12 +124,11 @@ Requires: atinject
Requires: glassfish-annotation-api
Requires: google-guice
Requires: guava
Requires: hawtjni-runtime
Requires: httpcomponents-client
Requires: httpcomponents-core
Requires: jansi
Requires: jansi-native
Requires: javapackages-tools
Requires: jboss-interceptors-1.2-api
Requires: jcl-over-slf4j
Requires: junit
Requires: maven-resolver-api
@ -186,6 +185,8 @@ BuildArch: noarch
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
# not really used during build, but a precaution
find -name '*.jar' -not -path '*/test/*' -delete
@ -220,9 +221,6 @@ sed -i "s/distributionName=.*/distributionName=Apache\ Maven/" `find -name build
%{mvn_alias} :maven-resolver-provider :maven-aether-provider
# xmvn depends on this version, so we want to avoid duplicate apache-commons-lang3 jars in xmvn
%pom_xpath_set pom:project/pom:properties/pom:commonsLangVersion "3.8.1"
%build
mkdir -p lib
build-jar-repository -s lib \
@ -232,6 +230,7 @@ build-jar-repository -s lib \
commons-io \
guava/guava \
guice/google-guice-no_aop \
jboss-interceptors-1.2-api \
jdom2/jdom2 \
maven-resolver/maven-resolver-api \
maven-resolver/maven-resolver-impl \
@ -282,7 +281,7 @@ for i in \
done
%install
%{mvn_install}
%mvn_install
%fdupes %{buildroot}%{_javadocdir}
install -d -m 755 %{buildroot}%{homedir}/boot
@ -296,25 +295,21 @@ chmod -x %{buildroot}%{homedir}/bin/*.cmd %{buildroot}%{homedir}/bin/*.conf
# Transitive deps of wagon-http, missing because of unshading
build-jar-repository -p %{buildroot}%{homedir}/lib \
objectweb-asm/asm \
cdi-api/cdi-api \
commons-cli \
commons-codec \
commons-io \
apache-commons-lang3 \
commons-logging \
guava/guava \
guice/google-guice-no_aop \
hamcrest/core \
hawtjni/hawtjni-runtime \
httpcomponents/httpclient \
httpcomponents/httpcore \
jansi/jansi \
jansi-native/jansi-linux \
jansi-native/jansi-native \
jboss-interceptors-1.2-api \
jsoup/jsoup \
atinject \
slf4j/jcl-over-slf4j \
glassfish-annotation-api \
junit \
maven-resolver/maven-resolver-api \
maven-resolver/maven-resolver-connector-basic \
maven-resolver/maven-resolver-impl \
@ -334,10 +329,13 @@ build-jar-repository -p %{buildroot}%{homedir}/lib \
slf4j/api \
maven-wagon/file \
maven-wagon/http \
maven-wagon/http-shared \
maven-wagon/provider-api
cp %{buildroot}%{_javadir}/%{name}/*.jar %{buildroot}%{homedir}/lib/
ln -sf %{_libdir}/jansi/libjansi.so %{buildroot}%{homedir}/lib/jansi-native/
build-jar-repository -p %{buildroot}%{homedir}/boot \
plexus-classworlds

View File

@ -1,120 +0,0 @@
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java 2022-01-13 07:08:06.182993103 +0100
@@ -157,7 +157,7 @@
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track extension usage
}
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java 2022-01-13 07:10:30.471820999 +0100
@@ -198,7 +198,7 @@
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java 2022-01-13 07:10:02.863663262 +0100
@@ -200,7 +200,7 @@
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track plugin usage
}
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java 2022-01-13 07:12:29.108498755 +0100
@@ -240,7 +240,7 @@
}
@Override
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java 2022-01-13 07:11:14.312071457 +0100
@@ -135,7 +135,7 @@
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track record usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
index 4d01aca4f..c0fda73c6 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
@@ -94,8 +94,8 @@ CacheRecord put( Key key, ClassRealm extensionRealm, ExtensionDescriptor extensi
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -94,8 +94,8 @@ CacheRecord put( Key key, ClassRealm extensionRealm, ExtensionDescriptor extensi
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
index 11f5d701f..cf17fe3d8 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
@@ -97,8 +97,8 @@ Key createKey( Plugin plugin, DependencyFilter extensionFilter, List<RemoteRepos
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -97,8 +97,8 @@ Key createKey( Plugin plugin, DependencyFilter extensionFilter, List<RemoteRepos
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
index 78c3ae6f3..f4aa66f78 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
@@ -90,8 +90,8 @@ Key createKey( Plugin plugin, ClassLoader parentRealm, Map<String, ClassLoader>
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -90,8 +90,8 @@ Key createKey( Plugin plugin, ClassLoader parentRealm, Map<String, ClassLoader>
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
index 8d8ad790e..690392da5 100644
--- a/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
@@ -96,8 +96,8 @@ Key createKey( MavenProject project, Collection<String> scopesToCollect, Collect
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -96,8 +96,8 @@ Key createKey( MavenProject project, Collection<String> scopesToCollect, Collect
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java 2022-01-13 07:11:56.088310105 +0100
@@ -94,8 +94,8 @@
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -94,8 +94,8 @@
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java 2022-01-13 08:09:14.744957009 +0100
@@ -97,8 +97,8 @@
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -97,8 +97,8 @@
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java 2022-01-13 07:36:03.136896661 +0100
@@ -90,8 +90,8 @@
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -90,8 +90,8 @@
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java 2022-01-13 07:07:32.302798450 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java 2022-01-13 07:12:55.192647787 +0100
@@ -96,8 +96,8 @@
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -96,8 +96,8 @@
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--- apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java 2022-01-13 07:07:32.298798428 +0100
+++ apache-maven-3.8.4/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java 2022-01-13 07:11:45.096247306 +0100
@@ -85,8 +85,8 @@
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -85,8 +85,8 @@
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/